pub struct Attribute {Show 14 fields
pub id: AttributeId,
pub name: I18nString,
pub prefix: Option<I18nString>,
pub suffix: Option<I18nString>,
pub code: String,
pub icon: String,
pub icon_path: String,
pub db_code: u8,
pub denominator: Option<i64>,
pub is_percent: bool,
pub calculation_script: String,
pub order: i64,
pub is_ui_visible: bool,
pub description: I18nString,
}Fields
id: AttributeIdname: I18nStringprefix: Option<I18nString>suffix: Option<I18nString>code: Stringicon: Stringicon_path: Stringdb_code: u8denominator: Option<i64>is_percent: boolcalculation_script: Stringorder: i64is_ui_visible: booldescription: I18nStringTrait Implementations
Sourceimpl CustomType for Attribute
impl CustomType for Attribute
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Attribute
impl<'de> Deserialize<'de> for Attribute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Attribute
impl JsonSchema for Attribute
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Attribute
impl Tsify for Attribute
const DECL: &'static str = "export interface Attribute {\n id: AttributeId;\n name: I18nString;\n prefix: I18nString | null;\n suffix: I18nString | null;\n code: string;\n icon: string;\n icon_path: string;\n db_code: number;\n denominator: number | null;\n is_percent: boolean;\n calculation_script: string;\n order: number;\n is_ui_visible: boolean;\n description: I18nString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Attribute
impl StructuralPartialEq for Attribute