pub struct Item {
pub id: Uuid,
pub item_template_id: ItemTemplateId,
pub item_type: ItemType,
pub rarity: ItemRarity,
pub level: i64,
pub name: I18nString,
pub icon_url: String,
pub icon_path: String,
pub is_equipped: bool,
pub price: Vec<CurrencyUnit>,
pub experience: i64,
pub attributes: Vec<ItemAttribute>,
}Fields
id: Uuiditem_template_id: ItemTemplateIditem_type: ItemTyperarity: ItemRaritylevel: i64name: I18nStringicon_url: Stringicon_path: Stringis_equipped: boolprice: Vec<CurrencyUnit>experience: i64attributes: Vec<ItemAttribute>Trait Implementations
Sourceimpl CustomType for Item
impl CustomType for Item
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Item
impl<'de> Deserialize<'de> for Item
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Itemwhere
Self: DeserializeOwned,
impl FromWasmAbi for Itemwhere
Self: DeserializeOwned,
Sourceimpl JsonSchema for Item
impl JsonSchema for Item
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Itemwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Itemwhere
Self: DeserializeOwned,
Sourceimpl RefFromWasmAbi for Itemwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Itemwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Item
impl Tsify for Item
const DECL: &'static str = "export interface Item {\n id: Uuid;\n item_template_id: ItemTemplateId;\n item_type: ItemType;\n rarity: ItemRarity;\n level: number;\n name: I18nString;\n icon_url: string;\n icon_path: string;\n is_equipped: boolean;\n price: CurrencyUnit[];\n experience: number;\n attributes: ItemAttribute[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Itemwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Itemwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
impl Eq for Item
impl StructuralPartialEq for Item