pub struct ItemAttribute {
pub attr_id: AttributeId,
pub value: i32,
}Fields
attr_id: AttributeIdvalue: i32Trait Implementations
Sourceimpl Clone for ItemAttribute
impl Clone for ItemAttribute
Sourcefn clone(&self) -> ItemAttribute
fn clone(&self) -> ItemAttribute
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ItemAttribute
impl CustomType for ItemAttribute
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ItemAttribute
impl Debug for ItemAttribute
Sourceimpl<'de> Deserialize<'de> for ItemAttribute
impl<'de> Deserialize<'de> for ItemAttribute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ItemAttribute
impl Hash for ItemAttribute
Sourceimpl JsonSchema for ItemAttribute
impl JsonSchema for ItemAttribute
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ItemAttribute
impl PartialEq for ItemAttribute
Sourceimpl Serialize for ItemAttribute
impl Serialize for ItemAttribute
Sourceimpl Tsify for ItemAttribute
impl Tsify for ItemAttribute
const DECL: &'static str = "export interface ItemAttribute {\n attr_id: AttributeId;\n value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ItemAttribute
impl StructuralPartialEq for ItemAttribute