pub struct ItemRarity {
pub id: ItemRarityId,
pub name: I18nString,
pub text_color: String,
pub rarity_icon: String,
pub rarity_icon_path: String,
pub ribbon_icon: String,
pub ribbon_icon_path: String,
pub order: i64,
}Fields
id: ItemRarityIdname: I18nStringtext_color: Stringrarity_icon: Stringrarity_icon_path: Stringribbon_icon: Stringribbon_icon_path: Stringorder: i64Trait Implementations
Sourceimpl Clone for ItemRarity
impl Clone for ItemRarity
Sourcefn clone(&self) -> ItemRarity
fn clone(&self) -> ItemRarity
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ItemRarity
impl CustomType for ItemRarity
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ItemRarity
impl Debug for ItemRarity
Sourceimpl Default for ItemRarity
impl Default for ItemRarity
Sourcefn default() -> ItemRarity
fn default() -> ItemRarity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ItemRarity
impl<'de> Deserialize<'de> for ItemRarity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ItemRarity
impl Hash for ItemRarity
Sourceimpl JsonSchema for ItemRarity
impl JsonSchema for ItemRarity
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ItemRarity
impl PartialEq for ItemRarity
Sourceimpl Serialize for ItemRarity
impl Serialize for ItemRarity
Sourceimpl Tsify for ItemRarity
impl Tsify for ItemRarity
const DECL: &'static str = "export interface ItemRarity {\n id: ItemRarityId;\n name: I18nString;\n text_color: string;\n rarity_icon: string;\n rarity_icon_path: string;\n ribbon_icon: string;\n ribbon_icon_path: string;\n order: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ItemRarity
impl StructuralPartialEq for ItemRarity