pub struct ItemTemplate {
pub id: ItemTemplateId,
pub name: I18nString,
pub icon_url: String,
pub icon_path: String,
pub item_type: ItemType,
pub rarity_id: ItemRarityId,
pub attributes_settings: ItemAttributeSettings,
pub skin_id: Option<SkinId>,
pub exclude_from_mimic: bool,
}Fields
id: ItemTemplateIdname: I18nStringicon_url: Stringicon_path: Stringitem_type: ItemTyperarity_id: ItemRarityIdattributes_settings: ItemAttributeSettingsskin_id: Option<SkinId>exclude_from_mimic: boolTrait Implementations
Sourceimpl Clone for ItemTemplate
impl Clone for ItemTemplate
Sourcefn clone(&self) -> ItemTemplate
fn clone(&self) -> ItemTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemTemplate
impl Debug for ItemTemplate
Sourceimpl<'de> Deserialize<'de> for ItemTemplate
impl<'de> Deserialize<'de> for ItemTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ItemTemplate
impl JsonSchema for ItemTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ItemTemplate
impl Serialize for ItemTemplate
Sourceimpl Tsify for ItemTemplate
impl Tsify for ItemTemplate
const DECL: &'static str = "export interface ItemTemplate {\n id: ItemTemplateId;\n name: I18nString;\n icon_url: string;\n icon_path: string;\n item_type: ItemType;\n rarity_id: ItemRarityId;\n attributes_settings: ItemAttributeSettings;\n skin_id: SkinId | null;\n exclude_from_mimic: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>